@@ -12,7 +12,7 @@ use Compress::Zlib();
 use JSON();
 use overload '""' => 'string';
 
-our $VERSION = 0.16;
+our $VERSION = 0.17;
 
 sub new {
     my ( $class, $params ) = @_;
@@ -45,6 +45,7 @@ sub gzip {
 
 sub hashref {
     my ( $self, $ref ) = @_;
+    my $old = JSON->new()->utf8()->decode( $self->string() );
     if ( ( @_ > 1 ) && ( defined $ref ) ) {
         $self->_init();
         $self->version( $ref->{log}->{version} );
@@ -59,13 +60,16 @@ sub hashref {
         $self->entries( $ref->{log}->{entries} );
         $self->comment( $ref->{log}->{comment} );
     }
-    return;
+    return $old;
 }
 
 sub string {
     my ( $self, $string ) = @_;
     if ( defined $string ) {
-        $string =~ s/^(\x{ef}\x{bb}\x{bf})//smxg;
+        my $utf8_regex  = qr/\xef\xbb\xbf/smx;
+        my $utf16_regex = qr/(?:\xfe\xff|\xff\xfe)/smx;
+        my $utf32_regex = qr/(?:\x00\x00\xfe\xff|\xff\xfe\x00\x00)/smx;
+        $string =~ s/^(?:$utf8_regex|$utf16_regex|$utf32_regex)//smxg;
     }
     my $json = JSON->new();
     $json = $json->utf8();
@@ -478,7 +482,7 @@ Archive::Har - Provides an interface to HTTP Archive (HAR) files
 
 =head1 VERSION
 
-Version 0.16
+Version 0.17
 
 =for stopwords xml gzip stringified HAR gzipped gzipping JSON hashref gunzipping
 
@@ -517,7 +521,7 @@ $har->string() accepts a stringified version of an L<HTTP archive|http://www.sof
 
 =head2 hashref
 
-$har->hashref() accepts a hashref of the L<HTTP archive|http://www.softwareishard.com/blog/har-12-spec/> and parses it.  There is no return value.
+$har->hashref() accepts a hashref of the L<HTTP archive|http://www.softwareishard.com/blog/har-12-spec/> and parses it.  It returns a hashref of the previous state of the archive
 
 =head2 gzip
 
